@@ -547,8 +547,10 @@ class IrcBot(object):
         elif type(message) == Color:
             await self._send_message(message.str, channel)
         elif type(message) == list:
+            raw_msg = ""
             for msg in message:
-                await self._send_message(msg, channel)
+                raw_msg += str("PRIVMSG " + channel) + " :" + msg + " \r\n"
+            await self._enqueue_message(raw_msg)
         elif type(message) == Message:
             await self._send_message(message.message, message.channel)
 
