@@ -1,9 +1,11 @@
-#TODO make a class instead of this globals crap 
+# TODO make a class instead of this globals crap
 
 import collections
 import logging
 import re
 import sys
+import types
+from copy import deepcopy as _deepcopy
 from functools import wraps
 
 import validators
@@ -71,6 +73,8 @@ def regex_cmd_with_messsage(filters, acccept_pms=True, pass_data=False, **kwargs
 
 
 url_commands = []
+
+
 def url_handler(**kwargs):
     """url_handler. The function should take a string that is the matched url.
 
@@ -87,9 +91,14 @@ def url_handler(**kwargs):
 
     return wrap_cmd
 
+
 custom_handlers = {}
+
+
 def custom_handler(action, **kwargs):
-    """custom_handler. Add handlers for other user actions like join, quit, part..
+    """custom_handler. Add handlers for other user actions like join, quit,
+    part..
+
     :param action: str or list of strings with one or more of the possible actions
         Possible actions and function necessary arguments are:
         type             kwargs
@@ -100,7 +109,6 @@ def custom_handler(action, **kwargs):
         'join' -> {'nick', 'channel'}
         'quit' -> {'nick', 'text'}
         'part' -> {'nick', 'channel'}
-
     """
 
     def wrap_cmd(func):
@@ -118,7 +126,6 @@ def custom_handler(action, **kwargs):
     return wrap_cmd
 
 
-
 command_prefix = "!"
 _command_max_arguments = 10
 _NonSpace = r"\S"
@@ -185,7 +192,10 @@ def _reg_word(org, pref):
         + opt_close * len(org[len(pref) :])
     )
 
+
 _defined_command_dict = {}
+
+
 def setCommands(command_dict: dict, simplify=True, prefix="!"):
     """Defines commands for the bot from existing functions
     param: command_dict: Takes a dictionary of "command names": function's to call creating the commands for each of them.
@@ -269,29 +279,32 @@ def setCommands(command_dict: dict, simplify=True, prefix="!"):
 
 
 def setPrefix(prefix):
-    """setPrefix. Sets the prefix for arg commands
+    """setPrefix. Sets the prefix for arg commands.
 
     :param prefix: str prefix for commands
     """
     global command_prefix
     command_prefix = prefix
 
-def setParseOrderTopBottom(top_bottom:bool = True):
+
+def setParseOrderTopBottom(top_bottom: bool = True):
     """setParseOrder.
+
     :param top_bottom: bool -> if True then first defined regex expressions will overwrite last ones. Default is False
     """
     global parse_order
     parse_order = top_bottom
 
+
 def setMaxArguments(n):
     """setMaxArguments.
+
     :param n: number of arguments for callbacks in arg_command decorator
     """
     global command_max_arguments
     command_max_arguments = n
 
 
-
 # LOGGING SETUP
 
 
